@@ -1,7 +1,7 @@
 from .account import Account, Identity
 from .attachments import FileAttachment, ItemAttachment
 from .autodiscover import discover
-from .configuration import Configuration
+from .configuration import Configuration, O365InteractiveConfiguration
 from .credentials import (
     DELEGATE,
     IMPERSONATION,
@@ -36,10 +36,9 @@ from .settings import OofSettings
 from .transport import BASIC, CBA, DIGEST, GSSAPI, NTLM, OAUTH2, SSPI
 from .version import Build, Version
 
-__version__ = "5.1.0"
+__version__ = "5.4.2"
 
 __all__ = [
-    "__version__",
     "AcceptItem",
     "Account",
     "Attendee",
@@ -79,6 +78,7 @@ __all__ = [
     "Message",
     "NTLM",
     "NoVerifyHTTPAdapter",
+    "O365InteractiveConfiguration",
     "OAUTH2",
     "OAuth2AuthorizationCodeCredentials",
     "OAuth2Credentials",
@@ -101,6 +101,7 @@ __all__ = [
     "UTC",
     "UTC_NOW",
     "Version",
+    "__version__",
     "close_connections",
     "discover",
 ]
