@@ -40,6 +40,7 @@ from exchangelib.fields import (
     EmailAddressField,
     EWSElementField,
     ExtendedPropertyField,
+    ImAddressField,
     IntegerField,
     MailboxField,
     MailboxListField,
@@ -52,7 +53,7 @@ from exchangelib.fields import (
     TimeZoneField,
     URIField,
 )
-from exchangelib.indexed_properties import EmailAddress, PhoneNumber, PhysicalAddress
+from exchangelib.indexed_properties import EmailAddress, ImAddress, PhoneNumber, PhysicalAddress
 from exchangelib.properties import (
     Attendee,
     CompleteName,
@@ -160,6 +161,8 @@ class EWSTest(TimedTestCase, metaclass=abc.ABCMeta):
     def wipe_test_account(self):
         # Deletes up all deletable items in the test account. Not run in a normal test run
         self.account.root.wipe()
+        for rule in self.account.rules:
+            rule.delete()
 
     def bulk_delete(self, ids):
         # Clean up items and check return values
@@ -243,31 +246,33 @@ class EWSTest(TimedTestCase, metaclass=abc.ABCMeta):
         if isinstance(field, EmailAddressesField):
             addrs = []
             for label in EmailAddress.get_field_by_fieldname("label").supported_choices(version=self.account.version):
-                addr = EmailAddress(email=get_random_email())
-                addr.label = label
-                addrs.append(addr)
+                addrs.append(EmailAddress(email=get_random_email(), label=label))
+            return addrs
+        if isinstance(field, ImAddressField):
+            addrs = []
+            for label in ImAddress.get_field_by_fieldname("label").supported_choices(version=self.account.version):
+                addrs.append(ImAddress(im_address=get_random_email(), label=label))
             return addrs
         if isinstance(field, PhysicalAddressField):
             addrs = []
             for label in PhysicalAddress.get_field_by_fieldname("label").supported_choices(
                 version=self.account.version
             ):
-                addr = PhysicalAddress(
-                    street=get_random_string(32),
-                    city=get_random_string(32),
-                    state=get_random_string(32),
-                    country=get_random_string(32),
-                    zipcode=get_random_string(8),
+                addrs.append(
+                    PhysicalAddress(
+                        street=get_random_string(32),
+                        city=get_random_string(32),
+                        state=get_random_string(32),
+                        country=get_random_string(32),
+                        zipcode=get_random_string(8),
+                        label=label,
+                    )
                 )
-                addr.label = label
-                addrs.append(addr)
             return addrs
         if isinstance(field, PhoneNumberField):
             pns = []
             for label in PhoneNumber.get_field_by_fieldname("label").supported_choices(version=self.account.version):
-                pn = PhoneNumber(phone_number=get_random_string(16))
-                pn.label = label
-                pns.append(pn)
+                pns.append(PhoneNumber(phone_number=get_random_string(16), label=label))
             return pns
         if isinstance(field, EWSElementField):
             if field.value_cls == Recurrence:
