@@ -221,12 +221,28 @@ class EWSTimeZoneTest(TimedTestCase):
             return
         self.assertEqual(type_version, CLDR_WINZONE_TYPE_VERSION)
         self.assertEqual(other_version, CLDR_WINZONE_OTHER_VERSION)
-        self.assertDictEqual(tz_map, CLDR_TO_MS_TIMEZONE_MAP)
+        self.assertDictEqual(CLDR_TO_MS_TIMEZONE_MAP, tz_map)
 
         # Test IANA exceptions. This fails if available_timezones() returns timezones that we have not yet implemented.
         # If this fails in CI but not locally, you need to update the 'tzdata' package to the latest version.
         sanitized = list(t for t in zoneinfo.available_timezones() if not t.startswith("SystemV/") and t != "localtime")
-        self.assertEqual(set(sanitized) - set(EWSTimeZone.IANA_TO_MS_MAP), set())
+        # TODO: IANA removed timezones that zoneinfo still has
+        self.assertEqual(
+            set(sanitized) - set(EWSTimeZone.IANA_TO_MS_MAP),
+            {
+                "Europe/Uzhgorod",
+                "America/Rainy_River",
+                "America/Santa_Isabel",
+                "Australia/Currie",
+                "Pacific/Johnston",
+                "America/Pangnirtung",
+                "America/Yellowknife",
+                "Europe/Zaporozhye",
+                "America/Montreal",
+                "America/Nipigon",
+                "America/Thunder_Bay",
+            },
+        )
 
     @requests_mock.mock()
     def test_generate_failure(self, m):
